@@ -61,8 +61,6 @@
 CacheDatabase::CacheDatabase(const QSqlDatabase & other, QObject *parent)
 : QObject (parent)
 , dbMain (other)
-, nCountInbox (0)
-, nCountContacts (0)
 {
 }//CacheDatabase::CacheDatabase
 
@@ -193,26 +191,11 @@ CacheDatabase::init ()
     }
 }//CacheDatabase::init
 
-QSqlTableModel *
+ContactsModel *
 CacheDatabase::newContactsModel()
 {
-    QSqlTableModel *modelContacts = new QSqlTableModel(this, dbMain);
-    modelContacts->setTable (GV_CONTACTS_TABLE);
-    modelContacts->setEditStrategy (QSqlTableModel::OnManualSubmit);
-    modelContacts->setHeaderData (0, Qt::Horizontal, QObject::tr("Name"));
-    modelContacts->setHeaderData (1, Qt::Horizontal, QObject::tr("Link"));
-
-    QSqlQuery query;
-    query.setForwardOnly (true);
-    query.exec ("SELECT COUNT (*) FROM " GV_CONTACTS_TABLE);
-    if (query.next ()) {
-        bool bOk = false;
-        int val = query.value (0).toInt (&bOk);
-        nCountContacts = 0;
-        if (bOk) {
-            nCountContacts = val;
-        }
-    }
+    ContactsModel *modelContacts = new ContactsModel(this);
+    this->refreshContactsModel (modelContacts);
 
     return (modelContacts);
 }//CacheDatabase::newContactsModel
@@ -226,6 +209,16 @@ CacheDatabase::clearContacts ()
     query.exec ("DELETE FROM " GV_LINKS_TABLE);
 }//CacheDatabase::clearContacts
 
+void
+CacheDatabase::refreshContactsModel (ContactsModel *modelContacts)
+{
+    modelContacts->setQuery ("SELECT " GV_C_ID "," GV_C_NAME " "
+                             "FROM " GV_CONTACTS_TABLE " "
+                             "ORDER BY " GV_C_NAME, dbMain);
+    modelContacts->setHeaderData (0, Qt::Horizontal, QObject::tr("Id"));
+    modelContacts->setHeaderData (1, Qt::Horizontal, QObject::tr("Name"));
+}//CacheDatabase::refreshContactsModel
+
 bool
 CacheDatabase::getUserPass (QString &strUser, QString &strPass)
 {
@@ -391,51 +384,67 @@ CacheDatabase::deleteContact (const QString  &strLink)
         query.exec (QString ("DELETE FROM " GV_CONTACTS_TABLE " "
                              "WHERE " GV_C_ID "='%1'")
                     .arg (strLink));
-        nCountContacts--;
     }
 
     return (true);
 }//CacheDatabase::deleteContact
 
 bool
-CacheDatabase::insertContact (QSqlTableModel *modelContacts,
-                              const QString  &strName,
+CacheDatabase::insertContact (const QString  &strName,
                               const QString  &strLink)
 {
-    // Define fields and the record
-    QSqlField fldName(GV_C_NAME, QVariant::String);
-    QSqlField fldLink(GV_C_ID, QVariant::String);
-    QSqlRecord sqlRecord;
-    sqlRecord.append (fldName);
-    sqlRecord.append (fldLink);
-
-    // Add values to the record
-    sqlRecord.setValue (GV_C_NAME, QVariant (strName));
-    sqlRecord.setValue (GV_C_ID, QVariant (strLink));
-
     bool rv = false;
-    do // Begin cleanup block (not a loop)
-    {
-        this->deleteContact (strLink);
+    do { // Begin cleanup block (not a loop)
+        QSqlQuery query(dbMain);
+        query.setForwardOnly (true);
 
-        if (!modelContacts->insertRows (nCountContacts, 1))
-        {
-            qWarning ("Failed to insert row");
-            break;
+        query.exec (QString ("SELECT " GV_C_ID " FROM " GV_CONTACTS_TABLE " "
+                             "WHERE " GV_C_ID "='%1'")
+                    .arg (strLink));
+        if (query.next ()) {
+            query.exec (QString ("DELETE FROM " GV_CONTACTS_TABLE " "
+                                 "WHERE " GV_C_ID "='%1'")
+                        .arg (strLink));
         }
-        if (!modelContacts->setRecord (nCountContacts, sqlRecord))
-        {
-            qWarning ("Failed to set row record");
+
+        rv = query.exec (QString ("INSERT INTO " GV_CONTACTS_TABLE ""
+                                  "(" GV_C_ID
+                                  "," GV_C_NAME ") VALUES ('%1', '%2')")
+                            .arg (strLink)
+                            .arg (strName));
+        if (!rv) {
+            qWarning () << "Failed to insert row into contacts table. ID:["
+                        << strLink
+                        << "] name=["
+                        << strName
+                        << "]";
             break;
         }
 
-        nCountContacts++;
         rv = true;
     } while (0); // End cleanup block (not a loop)
 
     return (rv);
 }//CacheDatabase::insertContact
 
+quint32
+CacheDatabase::getContactsCount ()
+{
+    quint32 nCountContacts = 0;
+    QSqlQuery query;
+
+    query.setForwardOnly (true);
+    query.exec ("SELECT COUNT (*) FROM " GV_CONTACTS_TABLE);
+    if (query.next ()) {
+        bool bOk = false;
+        int val = query.value (0).toInt (&bOk);
+        if (bOk) {
+            nCountContacts = val;
+        }
+    }
+    return (nCountContacts);
+}//CacheDatabase::getContactsCount
+
 bool
 CacheDatabase::deleteContactInfo (const QString  &strLink)
 {
@@ -497,6 +506,8 @@ CacheDatabase::getContactFromLink (GVContactInfo &info)
                     GV_L_LINK "='%1'").arg (info.strLink);
     query.exec (strQ);
 
+    info.arrPhones.clear ();
+
     QString strType, strData;
     while (query.next ())
     {
@@ -649,19 +660,25 @@ CacheDatabase::refreshInboxModel (InboxModel *modelInbox,
     modelInbox->setQuery (strQ, dbMain);
     modelInbox->setHeaderData (0, Qt::Horizontal, QObject::tr("Name"));
     modelInbox->setHeaderData (1, Qt::Horizontal, QObject::tr("Link"));
+}//CacheDatabase::refreshInboxModel
 
+quint32
+CacheDatabase::getInboxCount ()
+{
+    quint32 nCountInbox = 0;
     QSqlQuery query;
     query.setForwardOnly (true);
     query.exec ("SELECT COUNT (*) FROM " GV_INBOX_TABLE);
     if (query.next ()) {
         bool bOk = false;
         int val = query.value (0).toInt (&bOk);
-        nCountInbox = 0;
         if (bOk) {
             nCountInbox = val;
         }
     }
-}//CacheDatabase::refreshInboxModel
+
+    return (nCountInbox);
+}//CacheDatabase::getInboxCount
 
 bool
 CacheDatabase::setLastInboxUpdate (const QDateTime &dateTime)
@@ -781,7 +798,6 @@ CacheDatabase::insertHistory (const GVHistoryEvent &hEvent)
             query.exec (QString ("DELETE FROM " GV_INBOX_TABLE " "
                                  "WHERE " GV_IN_ID "='%1'")
                         .arg (hEvent.id));
-            nCountInbox--;
         }
 
         rv = query.exec (QString ("INSERT INTO " GV_INBOX_TABLE ""
@@ -803,7 +819,6 @@ CacheDatabase::insertHistory (const GVHistoryEvent &hEvent)
             break;
         }
 
-        nCountInbox++;
         rv = true;
     } while (0); // End cleanup block (not a loop)
 
